//! \file    FilesViewer.cpp
//! \brief   Implementation of the FileViewer window for visual_YAO.
//! \version 2009/11/09 (yyyy/mm/dd)
//! \author  MAYAKI Abdouramane & MAYOMBO Alexis.


#include <QtGui>
#include "Include/FilesViewer.hpp"

//! \class FilesViewer(QWidget *parent) : QDialog(parent)
//! \brief Implementation of the FilesViewer for visual_YAO.



/*******************************************************************************************************************************/
FilesViewer::FilesViewer(QWidget *parent) : QDialog(parent) {

	setWindowTitle(tr("Arborescence des fichiers"));

    modeleFichiers = new QDirModel;
        modeleFichiers->setReadOnly(false);
        modeleFichiers->setSorting(QDir::DirsFirst | QDir::IgnoreCase | QDir::Name);

    vueFichiers = new QTreeView;
        vueFichiers->setModel(modeleFichiers);
        vueFichiers->setRootIndex(modeleFichiers->index("projects/"));
        vueFichiers->header()->setStretchLastSection(true);
        vueFichiers->header()->setSortIndicator(0, Qt::AscendingOrder);
        vueFichiers->header()->setClickable(true);
        vueFichiers->setHeaderHidden(true);
     QModelIndex index = modeleFichiers->index(QDir::currentPath() + "projects/");
        vueFichiers->expand(index);
        vueFichiers->scrollTo(index);
        vueFichiers->resizeColumnToContents(0);

    mkdirButton = new QPushButton(tr("&Creer un repertoire"));
    removeButton = new QPushButton(tr("&Supprimer"));
    boutonActualiser = new QPushButton("Actualiser");

    connect(mkdirButton, SIGNAL(clicked()), this, SLOT(createDirectory()));
    connect(removeButton, SIGNAL(clicked()), this, SLOT(remove()));
    connect(boutonActualiser, SIGNAL(clicked()), modeleFichiers, SLOT(refresh()));

    QHBoxLayout *buttonLayout = new QHBoxLayout;
        buttonLayout->addWidget(mkdirButton);
        buttonLayout->addWidget(removeButton);
        buttonLayout->addWidget(boutonActualiser);
        buttonLayout->addStretch();

    QVBoxLayout *mainLayout = new QVBoxLayout;
        mainLayout->addWidget(vueFichiers);
        mainLayout->addLayout(buttonLayout);
        setLayout(mainLayout);

    
}

/*******************************************************************************************************************************/
void FilesViewer::createDirectory()
{
    QModelIndex index = vueFichiers->currentIndex();
    if (!index.isValid())
        return;

    QString dirName = QInputDialog::getText(this, tr("Creer un repertoire"), tr("Nom du repertoire"));
    //QString dirName2 = QInputDialog::getText(this, tr("Creer un repertoire"), tr("Nom du repertoire"));
    if (!dirName.isEmpty()) {
        if (!modeleFichiers->mkdir(index, dirName).isValid())
            QMessageBox::information(this, tr("Creer un repertoire"),
                    tr("Impossible de creer le repertoire"));
    }
}

/*******************************************************************************************************************************/
void FilesViewer::remove()
{
    QModelIndex index = vueFichiers->currentIndex();
    if (!index.isValid())
        return;

    bool ok;
    if (modeleFichiers->fileInfo(index).isDir()) {
        ok = modeleFichiers->rmdir(index);
    } else {
        ok = modeleFichiers->remove(index);
    }
    if (!ok)
        QMessageBox::information(this, tr("Supprimer"),
                tr("Impossible de supprimer %1").arg(modeleFichiers->fileName(index)));
}

/*******************************************************************************************************************************/
//void FilesViewer::appelActualiser()
//{
    //modeleFichiers->refresh();
//}


/*******************************************************************************************************************************/
