#ifndef MAINWINDOW_HPP
#define MAINWINDOW_HPP

#include <QtGui>
#include <QMainWindow>
#include <QWorkspace>
#include <QPushButton>
#include <QTabWidget>
#include <QWidget>
#include "MainWindowController.hpp"

#include <QCloseEvent>

/*!
 * \class MainWindow
 * \brief MainWindow class for visual_YAO.
 */

class MainWindow : public QMainWindow  {
    Q_OBJECT

        public :
            /*!
             *  \brief Constructor
             *
             *  Constructor of the class MainWindow
             *
             */

                    MainWindow(QWidget *parent = 0);
			
                    void actionsBarreOutils(QWorkspace *espace, MainWindowController mwc);
                    void creerActions(MainWindowController mwc);
                    void creerBarreOutils();
                    void creerMenus();
                    void creerRepertoire();
                    void genererDefval();
                    void genererHat();
                    void genererSpace();
                    void genererCtin();
		    bool okToContinue();
		    bool maybeSave();
                    ~MainWindow();
	protected :
		   void closeEvent(QCloseEvent *event);

        public slots:
                    void activeBoutonsBarreOutils();
                    void cacherBarreOutils();
                    void desactiveBoutonsBarreOutils();
                    void appelGenererD();
                    void montrerActionCompilation();
                    void montrerActionGenererD();
                    void createNewProject();
                    void callHatModel();
                    void changeColorDefvalButton();
                    void changeColorHatButton();
		    void changeColorOptionButton();
                    void changeColorTrajButton();
                    void changeColorSpaceButton();
		    void changeColorOperaButton();
                    void changeColorModulButton();
                    void changeColorCtinButton();
		    void changeColorNetwardButton();
	            void changeColorInsertFCTButton();
                    void enConstruction();

        private :
                    // Les attributs des menus
                    QMenu *menuFichier;
                    QMenu *menuEdition;
                    QMenu *menuAffichage;
                    QMenu *menuExecution;
                    QMenu *menuConfig;
                    QMenu *menuAide;

                    // Les actions du menu Fichier
                        QAction *actionFichierDescription;
                        QAction *actionFichierHat;

                        //QAction *actionModule;
                        QAction *actionFichierInstruction;
                        QAction *actionGrapheModulaire;
                        QAction *actionInfosProjet;
                    QAction *actionNouveauProjet;
                    QAction *actionOuvrirProjet;
                    QAction *actionOuvrirProjetsRecents;
                    QAction *actionImporterProjet;
                    QAction *actionEnregistrerProjet;
                    QAction *actionEnregistrerSousProjet;
                    QAction *actionImprimerProjet;
                    QAction *actionSortieProjet;

                    // Les actions du menu edition
                    QAction *actionAnnuler;
                    QAction *actionRevenir;
                    QAction *actionCouper;
                    QAction *actionCopier;
                    QAction *actionColler;
                    QAction *actionSelectionnerTout;

                    // Les actions du menu affichage
                    QAction *actionCacherBarreOutils;
                    QAction *actionCacherFenetreApercu;
                    QAction *actionCacherFenetreProjet;
                    QAction *actionCacherFenetreDialog;
                    QAction *actionPleinEcran;

                    // Les actions du menu Execution
                    QAction *actionGenerationD;
                    QAction *actionCompilation;
                    QAction *actionExecution;

                    // Les actions du menu configuration
                    QAction *actionEditeur;

                    // Les actions du menu aide
                    QAction *actionDocYao;
                    QAction *actionRapport;

                    // La barre d'outils
                    QPushButton *m_defvalButton;
                    QPushButton *m_hatNameButton;
                    QPushButton *m_optionButton;
                    QPushButton *m_trajButton;
                    QPushButton *m_spaceButton;
                    QPushButton *m_operaButton;
                    QPushButton *m_netwardButton;
                    QPushButton *m_modulButton;
                    QPushButton *m_ctinButton;
                    QPushButton *m_orderButton;
                    QPushButton *m_insertFCTButton;
                    QToolBar *yaoToolBar; //Crée une barre d'outils
                    QStatusBar *barreEtat;
                    QWorkspace *espace;
                    QTableWidget *tableWidget;
                    QString curFile;
                    QDockWidget *fenetreProjet;
                    //MainWindowController mwc;
                    DefvalWindow *m_defvalCopy;
                    HatNameWindow *m_hatCopy;
                    OptionWindow *m_optionCopy;
                    TrajWindow *m_trajCopy;
                    SpaceWindow *m_spaceCopy;
                    OperaWindow *m_operaCopy;
                    NetwardWindow *m_netwardCopy;
                    ModulWindow *m_modulCopy;
                    CtinWindow *m_ctinCopy;
                    OrderWindow *m_orderCopy;
                    InsertFCTWindow *m_insertFCTCopy;

                    NewProjectWindow *copynp;
                    FilesViewer *fv;
                    std::string copyProjectName;
                    std::vector<std::string> theHeaderList;
                    std::string filename;
                    std::string filepath;
                    //!< les onglets 
                     QTabWidget *tabWidget;
                     QWidget *page1;
                     QWidget *page2; 
		     
		     
};
#endif // FENETREPRINCIPALE_HPP
