//! \file    NewProjectWindow.hpp
//! \brief   Declaration of the NewProjectWindow class, which gives the new project's name for each directory.
//!          Windows path manipulations.
//! \version 2009/12/09 (yyyy/mm/dd)
//! \author  MAYAKI Abdouramane.

#ifndef NEWPROJECTWINDOW_HPP
#define NEWPROJECTWINDOW_HPP

#include "src/Include/Entete.hpp"
#include "src/Include/FilesViewer.hpp"
#include <QLineEdit>
#include <QTextEdit>
#include <QInputDialog>
#include <QFormLayout>
#include <QHBoxLayout>
#include <QSpacerItem>
#include <QString>
#include <QMessageBox>
#include <QDir>
#include <QChar>
#include <string>
#include <iostream>
#include <iomanip>
#include <cstdlib>
#include <fstream>
#include <vector>
#include "../help/FilePath.hpp"


class NewProjectWindow : public QWidget {
    Q_OBJECT

    public :
            NewProjectWindow(QWidget *parent=0);

            void setNewProjectName(std::string chaine);                 //!< Sets project's name.
            std::string getNewProjectName();                            //!< Gets project's name.

            void setProjectPath(QString chaine);                        //!< Sets project's path.
            std::string getProjectPath();                               //!< Gets project's path.

            void createFile(std::string data, std::string extension);   //!< Create a file with the giving data and the giving file's extension.

            void setNewProjectList(std::string aNewProjectList);        //!< Sets a list of project's name.
            std::vector<std::string> getNewProjectList();              //!< Gets a list of project's name.

    public slots:

            void createProjectDirectory();                              //!< Create a directory for the new project.
            void createHatFile();                                       //!< Create the default's hat file.

    private :

            std::string newProjectName;
            std::string m_cheminProjet;
            std::string m_infosProjet;
            std::vector<std::string> newProjectList;
            std::string name;

            QLineEdit *ligneNomRep;
            QTextEdit *ligneInfos;

            QPushButton *m_creerRepertoireProjet;
            QPushButton *m_quitProjet;

            QHBoxLayout *m_layoutH;
            QFormLayout *m_layoutF;
            QSpacerItem *m_spacer;


        };

#endif // NEWPROJECTWINDOW_HPP
