/*!
 * \file    SpaceWindow.hpp
 * \brief   Space class for visual_YAO.
 * \version 2009/12/26 (yyyy/mm/dd)
 * \author  MAYAKI Abdouramane & MAYOMBO Alexis.
 */


#ifndef SPACEWINDOW_HPP
#define SPACEWINDOW_HPP
#include "src/Include/Entete.hpp"
#include "TrajWindow.hpp"
#include <QLineEdit>
#include <QLabel>
#include <QComboBox>
#include <QFormLayout>
#include <QGridLayout>
#include <QTableWidget>
#include <QStringList>
#include <QLabel>
#include <string> 
#include <QMessageBox>
/*!
 * \class SpaceWindow
 * \brief The header file of the SpaceWindow class for visual_YAO.
 */


class SpaceWindow : public QWidget {

    Q_OBJECT                                    /*!< Must be declared for using signals and slots.*/

    public :
            /*!
             *  \brief Constructor
             *
             *  Constructor of the class SpaceWindow
             *
             *  \param Table<Space> theSpaceTable
             */


            SpaceWindow(QStringList *trajData = NULL, QWidget *parent=0);     /*!< This function sets the file's name. */
            QStringList getData();              /*!< This function returns the space's data. */
	    	void toInitialize(); // Est appelée pour réinitialiser les champs.
	   		bool isString(std::string aString); // Teste si le parametre est une chaine.
	    	bool isInt(std::string aStringToInt);//Teste si le parametre est un entier.
		void addRow();                      /*!< This function is called to add row in the visual window model. */
		void testPresenceLigne();
            

    public slots:                               /*!< Functions called after a click. */

            void addSpaceRow();
            void deleteRow();                   /*!< This function is called to delete row from the Yao model. */
            void saveInYaoStructure();          /*!< This function is called to add data in the Yao model. */
            void callSpaceHelp();

    private :
            QLabel *m_spaceNameLabel;           /*!< Label of the QLineEdit. */
            QLabel *m_spaceTypeLabel;           /*!< The QComboBox's type label. */
            QLabel *m_spaceD1Label;             /*!< Label of the 1st dimension. */
            QLabel *m_spaceD2Label;
            QLabel *m_spaceD3Label;
            QLabel *m_spaceTrajLabel;

            QLineEdit *m_spaceNameLine;         /*!< Name of the space. */
            QLineEdit *m_spaceType;             /*!< Type of the space. */
            
            QComboBox *m_spaceD1;               /*!< Name of the 1st dimension. */
            QComboBox *m_spaceD2;               /*!< Name of the 2nd dimension. */
            QComboBox *m_spaceD3;               /*!< Name of the 3rd dimension. */
            QComboBox *m_spaceTrajname;         /*!< Name of the selected traj. Must be declared in the traj Window */

            QTableWidget *m_spaceTableView;     /*!< Name of the QTableWidget's object in whitch the objects are listed for the viewer. */

            QPushButton *m_spaceAddButton;      /*!< The button "add". */
            QPushButton *m_spaceEnregButton;    /*!< The button "save". */
            QPushButton *m_spaceDeleteButton;   /*!< The button "delete". */
            QPushButton *m_spaceHelpButton;
            QPushButton *m_spaceQuitButton;     /*!< The button "Quit". */

            QHBoxLayout *m_spaceLayout1H;       /*!< The 1st horizontal Layout's name. */
            QHBoxLayout *m_spaceLayout2H;       /*!< The 2nd horizontal Layout's name. */
            QVBoxLayout *m_spaceLayout1V;
			QGridLayout *m_spaceLayoutG;


            QVBoxLayout *m_layoutPrincipalSpace;/*!< The vertical Layout's name. */
            QFormLayout *m_layout1Space;        /*!< The only QFormLayout's name. */

            QStringList m_horizontalHeader;
            QStringList m_spaceData;
	    QStringList m_localData;
            //SpaceController m_spc;
            bool isCalled;
};
#endif // SPACEWINDOW_HPP
