//! \file    MainWindow.cpp
//! \brief   Implementation of the main Visual_YAO code.
//! \version 2009/11/06 (yyyy/mm/dd)
//! \author  MAYAKI Abdouramane & MAYOMBO Alexis
/*
  Nom du Fichier: MainWindow.cpp
  Nom de classe: MainWindow
  Role: Outre son role de fichier d'implémentation des méthodes, ce fichier
  Nombre de methodes:
  Nombre d'attributs:
  */

#include "Include/MainWindow.hpp"
#include<iostream>

//! \class MainWindow(QWidget *parent) : QMainWindow(parent)
//! \brief Implementation of the Main window for visual_YAO.


/*****************************************************************************************************************************/
/*
  Implementation du constructeur de la classe MainWindow

*/


MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent) {

 this->setWindowTitle("Fenêtre principale \"Visual Yao\"."); 	//Donne un titre à la fenêtre principale

	espace = new QWorkspace;    				//Crée un espace de travail. Ici, ça serait notre zone centrale
	
	MainWindowController & m_mwc = MainWindowController::getInstance(); 	

        copyProjectName = m_mwc.getProjectNameFromMWC();

	fv  = new FilesViewer(); 			//Création d'un espace montrant l'arborescence des fichiers sur le disque dûr.
	
	fenetreProjet                 = new QDockWidget("Projet", this);	// Réservation de l'espace pour la fenêtre projet
		fenetreProjet->setFeatures(QDockWidget::NoDockWidgetFeatures); 	//La fenêtre projet ne pourra être ni deplacée ni fermée.
		fenetreProjet->setWidget(fv); 			// L'arborescence des fichiers est incluse dans la fenêtre projet. 
        //QDockWidget *dock2            = new QDockWidget("Apercu", this);
	//addDockWidget(Qt::LeftDockWidgetArea, dock2);
        addDockWidget(Qt::LeftDockWidgetArea, fenetreProjet); //Positionnement de la fenêtre projet à gauche dans la QMainWindow.

	
    	setCentralWidget(espace); 	//Ici, se précise la zone centrale de la QMainWindow.
	// Appel des differentes méthodes crées.
    	creerActions(m_mwc); 		//Appel de la methode creerActions(), voir le code ci-après.
    	creerMenus();  			// Appel de la méthode creerMenu(), voir le code ci-après.
    	creerBarreOutils();             //Cree la barre d'outils
     	barreEtat = statusBar(); 	//Affiche la barre d'état.
	
	QDockWidget *dock3            = new QDockWidget("Résultats", this);/////////////////////////////////
    		dock3->setAllowedAreas(Qt::BottomDockWidgetArea | Qt::RightDockWidgetArea); 
	addDockWidget(Qt::BottomDockWidgetArea, dock3);
    	tabWidget = new QTabWidget(dock3);//(this);
    		dock3->setWidget(tabWidget);  
    //tabWidget->setGeometry(QRect(310, 565, 969, 106));
    		page1 = new QWidget();
   // page1->setObjectName(QString::fromUtf8("tab"));
    		tabWidget->addTab(page1, "          compilation               ");
    		page2 = new QWidget();
    ///page2->setObjectName(QString::fromUtf8("tab_2"));
    		tabWidget->addTab(page2, "                 Exécution          ");
    //QTabWidget::setTabPosition(QTabWidget::self, South);
    //horizontalLayout->addWidget(tabWidget);
     		tabWidget->setCurrentIndex(1);



   this->showMaximized(); // Maximise toujours la fenetre principale.

}

/********************************* Implémentation de la methode creerMenus() *************************************************/

void MainWindow::creerMenus() {

    menuFichier = menuBar()->addMenu(tr("&Fichier"));
        menuFichier->addAction(actionNouveauProjet);
        menuFichier->addAction(actionOuvrirProjet);
        menuFichier->addAction(actionOuvrirProjetsRecents);
        menuFichier->addSeparator(); // Met une ligne horizontale entre les menus
        //menuFichier->addAction(actionImporterProjet);
        menuFichier->addSeparator();
        menuFichier->addAction(actionEnregistrerProjet);
        menuFichier->addAction(actionEnregistrerSousProjet);
        menuFichier->addSeparator();
        menuFichier->addAction(actionSortieProjet);
    menuEdition = menuBar()->addMenu("&Edition");
        menuEdition->addAction(actionFichierDescription);
        menuEdition->addAction(actionFichierHat);
        //nouveau->addAction(actionModule);
        menuEdition->addAction(actionFichierInstruction);
        menuEdition->addAction(actionGrapheModulaire);
        menuEdition->addAction(actionInfosProjet);

    menuAffichage = menuBar()->addMenu("&Affichage");
        menuAffichage->addAction(actionCacherBarreOutils);

        menuAffichage->addAction(actionCacherFenetreApercu);
        menuAffichage->addAction(actionCacherFenetreProjet);
        menuAffichage->addAction(actionCacherFenetreDialog);
    menuExecution = menuBar()->addMenu("&Exécution");
        menuExecution->addAction(actionGenerationD);
        menuExecution->addAction(actionCompilation);
        menuExecution->addAction(actionExecution);
    menuConfig    = menuBar()->addMenu("&Configuration");
        menuConfig->addAction(actionEditeur);
    menuAide = menuBar()->addMenu(tr("&Aide"));
        menuAide->addAction(actionDocYao);
        menuAide->addAction(actionRapport);

}

/********************************** Implémentation de la methode creerActions() **********************************************/
void MainWindow::creerActions(MainWindowController mwc)  {

 // Les actions du menu fichier
    actionNouveauProjet = new QAction(tr("Nouveau projet"), this);
        actionNouveauProjet->setIcon(QIcon("Images/icons/newfile.png"));
        actionNouveauProjet->setStatusTip("Créer un nouveau projet");
        //connect(actionNouveauProjet, SIGNAL(triggered()), this, SLOT(activeBoutonsBarreOutils()));
        connect(actionNouveauProjet, SIGNAL(triggered()), this, SLOT(createNewProject()));
        //connect(actionNouveauProjet, SIGNAL(triggered()), this, SLOT(montrerActionGenererD()));
    actionOuvrirProjet = new QAction(tr("&Ouvrir un projet"), this);
        actionOuvrirProjet->setIcon(QIcon("Images/icons/openfile.png"));
        actionOuvrirProjet->setShortcut(tr("Ctrl+O"));
        actionOuvrirProjet->setStatusTip("Ouvrir un projet existant");
        connect(actionOuvrirProjet, SIGNAL(triggered()), this, SLOT(ouvrirProjet()));
        //connect(actionOuvrirProjet, SIGNAL(triggered()), this, SLOT(montrerActionCompilation()));
    actionOuvrirProjetsRecents = new QAction(tr("Ouvrir projets recents"), this);
        //compilAction->setIcon(QIcon(""));
        actionOuvrirProjetsRecents->setShortcut(tr("Ctrl+P"));
        actionOuvrirProjetsRecents->setStatusTip("Projets recemment ouverts");
     //connect(compilAction, SIGNAL(triggered()), this, SLOT());
    //actionImporterProjet = new QAction(tr("&Importer"), this);
        //runAction->setIcon(QIcon(""));
      //  actionImporterProjet->setShortcut(tr("Ctrl+E"));
      //  actionImporterProjet->setStatusTip("Importer un projet");
     //connect(runAction, SIGNAL(triggered()), this, SLOT());
     actionEnregistrerProjet = new QAction(tr("Enregi&strer"), this);
        actionEnregistrerProjet->setIcon(QIcon("Images/icons/save.png"));
        actionEnregistrerProjet->setEnabled(false); // Option désactivée par défaut.
        actionEnregistrerProjet->setStatusTip("Pour sauvegarder le projet en cours");
     actionEnregistrerSousProjet = new QAction(tr("Enregistrer sous"), this);
        actionEnregistrerSousProjet->setIcon(QIcon("Images/icons/saveas.png"));
        actionEnregistrerSousProjet->setEnabled(false); // Option désactivée par défaut.
        actionEnregistrerSousProjet->setStatusTip("En le projet sous un autre nom");
     actionImprimerProjet = new QAction(tr("Imprimer"), this);
        actionImprimerProjet->setStatusTip("Options d'impression");
     actionSortieProjet = new QAction(tr("&Sortir"), this);
        actionSortieProjet->setIcon(QIcon("Images/icons/exit.png"));
        actionSortieProjet->setShortcut(tr("Ctrl+Q"));
        actionSortieProjet->setStatusTip("Fermer le programme");
        connect(actionSortieProjet, SIGNAL(triggered()), this, SLOT(close()));

     // Les actions du menu Edition
     actionFichierDescription = new QAction(tr("Fichier de description (.d)"), this);


        connect(actionFichierDescription, SIGNAL(triggered()), this, SLOT(appelGenererD()));


     actionFichierHat = new QAction(tr("Fichier  (.h)"), this);
            //actionModule = new QAction(tr("Module"), this);
            actionFichierInstruction = new QAction(tr("Fichier instruction (.i)"), this);
            actionGrapheModulaire = new QAction(tr("Graphe modulaire"), this);
            actionInfosProjet = new QAction(tr("Edition infos projet"), this);

     // Les actions du menu Affichage
     actionCacherBarreOutils = new QAction(tr("Cacher la barre d'outils"), this);
        actionCacherBarreOutils->setCheckable(true);
        connect(actionCacherBarreOutils, SIGNAL(triggered()), this, SLOT(cacherBarreOutils()));
     actionCacherFenetreApercu = new QAction(tr("Cacher la fenetre apercu"), this);
        actionCacherFenetreApercu->setCheckable(true);
     actionCacherFenetreProjet = new QAction(tr("Cacher la fenetre Projet"), this);
        actionCacherFenetreProjet->setCheckable(true);
     actionCacherFenetreDialog = new QAction(tr("Cacher la fenetre dialog"), this);
        actionCacherFenetreDialog->setCheckable(true);
     actionPleinEcran = new QAction(tr("Plein ecran"), this);
        actionPleinEcran->setCheckable(true);

     // Les actions du menu Execution
     actionGenerationD = new QAction(tr("Generer le fichier .d"), this);
        actionGenerationD->setEnabled(false);
        connect(actionGenerationD, SIGNAL(triggered()), this, SLOT(appelGenererD()));

     actionCompilation = new QAction(tr("Compilation"), this);
        actionCompilation->setEnabled(false);
     actionExecution = new QAction(tr("Execution"), this);
        actionExecution->setEnabled(false);

     // Les actions du menu Configuration
     actionEditeur = new QAction(tr("Editeur par defaut"), this);

     // Les actions du menu Aide
     actionDocYao = new QAction(tr("Doc Yao"), this);
     actionRapport = new QAction(tr("Rapport"), this);
    //aproposYao = new QAction(tr("A propos de Yao"), this);

     // Les actions de la barre d'outils

      actionsBarreOutils(espace, mwc);

}

/********************************* Implémentation de la methode creerBarreOutils() *******************************************/

void MainWindow::creerBarreOutils() {

    yaoToolBar = addToolBar(tr("&YaoToolbar"));

    yaoToolBar->addWidget(m_defvalButton);
    yaoToolBar->addWidget(m_hatNameButton);
    yaoToolBar->addWidget(m_optionButton);
    yaoToolBar->addWidget(m_trajButton);
    yaoToolBar->addWidget(m_spaceButton);
    yaoToolBar->addWidget(m_operaButton);
    yaoToolBar->addWidget(m_netwardButton);
    yaoToolBar->addWidget(m_modulButton);
    yaoToolBar->addWidget(m_ctinButton);
    yaoToolBar->addWidget(m_orderButton);
    yaoToolBar->addWidget(m_insertFCTButton);
    yaoToolBar->addSeparator();
    yaoToolBar->addAction(actionSortieProjet);
    //yaoToolBar->hide();

}

/******************************** Implémentation de la methode cacherBarreOutils *********************************************/

void MainWindow::cacherBarreOutils() {
 yaoToolBar->hide();
 barreEtat->showMessage(tr("La barre des outils est cachée!"), 2000);

}
/*****************************************************************************************************************************/
void MainWindow::callHatModel(){
        //mwc.setFileListController("wwww.h");
	MainWindowController & mwc2 = MainWindowController::getInstance(); 
        m_hatCopy = mwc2.getHatName();
        espace->addWindow(m_hatCopy);

        m_hatCopy->show();

}


/********************************** Implementation de la methode actionsBarreOutils() ****************************************/
void MainWindow::actionsBarreOutils(QWorkspace *espace, MainWindowController mwc) {

     m_defvalButton    = new QPushButton(tr("Defval"), this);
	m_defvalButton->setToolTip("Bouton désactivé. Vous devez d'abord creer un nouveau projet ou en ouvrir un.");
        m_defvalCopy = mwc.getDefval();
        espace->addWindow(m_defvalCopy);
        m_defvalCopy->hide();
        connect(m_defvalButton, SIGNAL(clicked()), m_defvalCopy, SLOT(show()));
        connect(m_defvalButton, SIGNAL(clicked()), this, SLOT(changeColorDefvalButton()));
	connect(espace, SIGNAL(windowActivated(m_defvalButton)), espace, SLOT(setActiveWindow(m_defvalButton)));
    	//connect(m_defvalButton, SIGNAL(clicked()), espace, SLOT(activeWindow()));

    m_hatNameButton   = new QPushButton(tr("Hatname"), this);
        m_hatCopy = mwc.getHatName();
        //m_hatCopy->setLocalProjectName(copynp->getNewProjectName());
        espace->addWindow(m_hatCopy);
        m_hatCopy->hide();
        connect(m_hatNameButton, SIGNAL(clicked()), m_hatCopy, SLOT(show()));
        connect(m_hatNameButton, SIGNAL(clicked()), this, SLOT(changeColorHatButton()));
     m_optionButton    = new QPushButton(tr("Option"), this);
        m_optionCopy = mwc.getOption();
        espace->addWindow(m_optionCopy);
        m_optionCopy->hide();
        connect(m_optionButton, SIGNAL(clicked()), m_optionCopy, SLOT(show()));
        connect(m_optionButton, SIGNAL(clicked()), this, SLOT(changeColorOptionButton()));

     m_trajButton      = new QPushButton(tr("Traj"), this);
        m_trajCopy = mwc.getTraj();
        espace->addWindow(m_trajCopy);
        m_trajCopy->hide();
        connect(m_trajButton, SIGNAL(clicked()), m_trajCopy, SLOT(show()));
        connect(m_trajButton, SIGNAL(clicked()), this, SLOT(changeColorTrajButton()));
     m_spaceButton     = new QPushButton(tr("Space"), this);
        m_spaceCopy = mwc.getSpace();
        espace->addWindow(m_spaceCopy);
        m_spaceCopy->hide();
        connect(m_spaceButton, SIGNAL(clicked()), m_spaceCopy, SLOT(show()));
        connect(m_spaceButton, SIGNAL(clicked()), this, SLOT(changeColorSpaceButton()));
     m_operaButton     = new QPushButton(tr("Opera"), this);
        m_operaCopy = mwc.getOpera();
        espace->addWindow(m_operaCopy);
        m_operaCopy->hide();
        connect(m_operaButton, SIGNAL(clicked()), m_operaCopy, SLOT(show()));
        connect(m_operaButton, SIGNAL(clicked()), this, SLOT(changeColorOperaButton()));

     m_netwardButton   = new QPushButton(tr("Netward"), this);
        m_netwardCopy = mwc.getNetward();
        espace->addWindow(m_netwardCopy);
        m_netwardCopy->hide();
        connect(m_netwardButton, SIGNAL(clicked()), m_netwardCopy, SLOT(show()));
        connect(m_netwardButton, SIGNAL(clicked()), this, SLOT(changeColorNetwardButton()));

     m_modulButton     = new QPushButton(tr("Module"), this);
        m_modulCopy = mwc.getModul();
        espace->addWindow(m_modulCopy);
        m_modulCopy->hide();
        connect(m_modulButton, SIGNAL(clicked()), m_modulCopy, SLOT(show()));
        connect(m_modulButton, SIGNAL(clicked()), this, SLOT(changeColorModulButton()));
     m_ctinButton      = new QPushButton(tr("Ctin"), this);
        m_ctinCopy = mwc.getCtin();
        espace->addWindow(m_ctinCopy);
        m_ctinCopy->hide();
        connect(m_ctinButton, SIGNAL(clicked()), m_ctinCopy, SLOT(show()));
        connect(m_ctinButton, SIGNAL(clicked()), this, SLOT(changeColorCtinButton()));
     m_orderButton     = new QPushButton(tr("Order"), this);
      /*  m_orderCopy = mwc.getOrder();
        espace->addWindow(m_orderCopy);
        m_orderCopy->hide();
        connect(m_orderButton, SIGNAL(clicked()), m_orderCopy, SLOT(show()));*/
        connect(m_orderButton, SIGNAL(clicked()), this, SLOT(enConstruction()));

     m_insertFCTButton = new QPushButton(tr("Insert_fct"), this);
        m_insertFCTCopy = mwc.getInsertFCT();
        espace->addWindow(m_insertFCTCopy);
        m_insertFCTCopy->hide();
        connect(m_insertFCTButton, SIGNAL(clicked()), m_insertFCTCopy, SLOT(show()));
        connect(m_insertFCTButton, SIGNAL(clicked()), this, SLOT(changeColorInsertFCTButton()));

     desactiveBoutonsBarreOutils(); // Désactive tous les boutons de la barre d'outils
}
/*********************************** Implémentation de la methode activeBoutonsBarreOutils() *********************************/

void MainWindow::activeBoutonsBarreOutils() {

    m_defvalButton->setEnabled(true);
    m_hatNameButton->setEnabled(true);
    m_optionButton->setEnabled(true);
    m_trajButton->setEnabled(true);
    m_spaceButton->setEnabled(true);
    m_operaButton->setEnabled(true);
    m_netwardButton->setEnabled(true);
    m_modulButton->setEnabled(true);
    m_ctinButton->setEnabled(true);
    m_orderButton->setEnabled(true);
    m_insertFCTButton->setEnabled(true);

}
/********************************** Implémentation de la methode desactiveBoutonsBarreOutils() *******************************/

void MainWindow::desactiveBoutonsBarreOutils() {

        m_defvalButton->setEnabled(false);
        m_hatNameButton->setEnabled(false);
        m_optionButton->setEnabled(false);
        m_trajButton->setEnabled(false);
        m_spaceButton->setEnabled(false);
        m_operaButton->setEnabled(false);
        m_netwardButton->setEnabled(false);
        m_modulButton->setEnabled(false);
        m_ctinButton->setEnabled(false);
        m_orderButton->setEnabled(false);
        m_insertFCTButton->setEnabled(false);
}

/********************************* Implémentation de la methode nouveauProjet (SLOT) *****************************************/

void MainWindow::createNewProject() {

        activeBoutonsBarreOutils();
        copynp = new NewProjectWindow;//mwc4.getNP();
        espace->addWindow(copynp);
        copynp->show();
	//mwc4.getNewProjectInstance();
	//this.setSizeConstraint(QLayout::SetDefaultConstraint);
        montrerActionGenererD();

//return true;
  }
/*********************************** Implémentation de la methode sauvegardeProjet() *****************************************/

/*bool MainWindow::sauvegarderProjet() {


    statusBar()->showMessage(tr("Projet sauvegarde"), 2000);
    return true;

}*/

/*********************************** Implémentation de la methode changeColorDefvalButton() (SLOT) ************************/

void MainWindow::changeColorDefvalButton() {

 m_defvalButton->setStyleSheet("background-color: rgb(180, 180, 180)");
}

/*********************************** Implémentation de la méthode ********************************************************/
void MainWindow::changeColorHatButton() {

    m_hatNameButton->setStyleSheet("background-color: rgb(180, 180, 180)");
}

/*********************************** Implémentation de la méthode ********************************************************/
 void MainWindow::changeColorOptionButton() {

     m_optionButton->setStyleSheet("background-color: rgb(180, 180, 180)");
 }

/************************************************************************************************************************/
void MainWindow::changeColorTrajButton() {

    m_trajButton->setStyleSheet("background-color: rgb(180, 180, 180)");
}

/************************************************************************************************************************/
void MainWindow::changeColorSpaceButton() {

    m_spaceButton->setStyleSheet("background-color: rgb(180, 180, 180)");

}
/********************************** Implémentation de la méthode changeColorOperaButton ****************************/
void MainWindow::changeColorOperaButton() {
 
     m_operaButton->setStyleSheet("background-color: rgb(180, 180, 180)");
 
 }

/************************************************************************************************************************/
void MainWindow::changeColorModulButton() {

    m_modulButton->setStyleSheet("background-color: rgb(180, 180, 180)");
}

/************************************************************************************************************************/
void MainWindow::changeColorCtinButton() {

    m_ctinButton->setStyleSheet("background-color: rgb(180, 180, 180)");

}

/************************************************************************************************************************/
void MainWindow::changeColorNetwardButton() {

    m_netwardButton->setStyleSheet("background-color: rgb(180, 180, 180)");

}
/************************************************************************************************************************/
void MainWindow::changeColorInsertFCTButton() {

    m_insertFCTButton->setStyleSheet("background-color: rgb(180, 180, 180)");

}


/********************************** Implémentation de la methode montrerActionGenererD() *********************************************/

void MainWindow::montrerActionGenererD() {
    actionGenerationD->setEnabled(true);
}

/********************************** Implémentation de la methode montrerActionCompilation() ******************************/

void MainWindow::montrerActionCompilation() {
    actionCompilation->setEnabled(true);
}

/*********************************** Implémentation de la methode appelGenererD *******************************************/

void MainWindow::appelGenererD()
{
    //theHeaderList = m_hatCopy->getTheHeaderList();
    //theHeaderList = mwc.getTheHeaderList(0);
    filename = copynp->getNewProjectName();
    filepath = "projects/" + filename + "/" + filename + ".d";
    //SpaceController test = SpaceController::getInstance();
	//test.spaceHelpControl() ;
    ofstream description(filepath.c_str(), ios::out | ios::binary | ios::trunc);
        if(!description.is_open())
                throw ofstream::failure("couldn't create " + filename);

         description << "#DEFVAL pour definir des directives  ------------------------------------------DEFVAL" << endl;

       for (QStringList::iterator it = m_defvalCopy->getDataDefval().begin(); it != m_defvalCopy->getDataDefval().end(); it++)
            description << "defval " << it->toStdString() << endl;
            description << endl;
        description << "#HAT_NAME pour definir des nom de fichiers ---------------------------------------hat" << endl;

       for(QStringList::iterator it = m_hatCopy->getHatList().begin(); it != m_hatCopy->getHatList().end(); it++)
               description << "hat_name \"" << it->toStdString() << "\"" << endl;
                   description << endl;
	
	for(QStringList::iterator it = m_optionCopy->getOptionData().begin(); it != m_optionCopy->getOptionData().end(); it++)
               description << "option " << it->toStdString() << endl;
                   description << endl;

               description << "#TRAJECTOIRES (DIM) -------------------------------------------------------------TRAJ" << endl;

       for (QStringList::iterator it = m_trajCopy->getDataTraj().begin(); it != m_trajCopy->getDataTraj().end(); it++)
           description << "traj " << it->toStdString() << endl;
            description << endl;
            description << "#DIMENSION ------------------------------------------------------------------------DIM" << endl; 

       for (QStringList::iterator it = m_spaceCopy->getData().begin(); it != m_spaceCopy->getData().end(); it++)
            description << "space " << it->toStdString() << endl;
            description << endl;
            description << "#NETWARD ---------------------------------------------------------------------------MODUL" << endl;

       for (QStringList::iterator it = m_netwardCopy->getDataNetward().begin(); it != m_netwardCopy->getDataNetward().end(); it++)
            description << "netward " << it->toStdString() << endl;
            description << endl;
            description << "#MODUL ---------------------------------------------------------------------------MODUL" << endl;
   
       for (QStringList::iterator it = m_modulCopy->getDataModul().begin(); it != m_modulCopy->getDataModul().end(); it++)
           description << "modul " << it->toStdString() << endl;
           description << endl;
           description << "#CONNECTIONS------------------------------------------------------------------------CTIN+M" << endl;

       for (QStringList::iterator it = m_ctinCopy->getDataCtin().begin(); it != m_ctinCopy->getDataCtin().end(); it++)
           description << "ctin " << it->toStdString() << endl;
           description << "#USER FUNCTIONS	----------------------------------------------------------------INSERT_FCT" << endl;
            description << endl;

       for (QStringList::iterator it = m_insertFCTCopy->getDataFCT().begin(); it != m_insertFCTCopy->getDataFCT().end(); it++)
           description << "insert_fct " << it->toStdString() << endl;
            description << endl;
    //genererDefval();
    //genererHat();
    //genererSpace();

    description.close();
}
/************************************ Implémentation du slot enConstruction **********************************************/
void MainWindow::enConstruction() {

    QMessageBox::about(this, tr("Attention!"),("<p> Parametre en cours de construction!"
                                                                  "<p>Cliquez sur le bouton ok pour fermer cette fenetre."));

}
/************************************ Implementation de la méthode genererDefval *****************************************/
/*void MainWindow::genererDefval() {

           // The hat file genereted automatically.
        ofstream description(filepath.c_str(), ios::out | ios::binary | ios::trunc);
        if(!description.is_open())
                throw ofstream::failure("couldn't create " + filename);
        //theHeaderList = mwc.getTheHeaderList;

        //for(vector<string>::iterator it = theHeaderList.begin(); it != theHeaderList.end(); it++)

            //description <<

        //for(vector<string>::iterator it = theHeaderList.begin(); it != theHeaderList.end(); it++)

          //      description << *it << endl;

        description << endl;

        description.close();
        //cout << "voici :" << filename << endl;
 } */

/******************************** Implémentation de la methode  creerRepertoire**********************************************/
/*void MainWindow::genererHat() {

        ofstream description(filepath.c_str(), ios::out | ios::binary | ios::trunc);
        if(!description.is_open())
                throw ofstream::failure("couldn't create " + filename);


        for(vector<string>::iterator it = theHeaderList.begin(); it != theHeaderList.end(); it++)
                description << "hat_name \"" << *it << "\"" << endl;
                   description << endl;

        description.close();
}*/

/*********************************** Implémentation de la méthode closeEvent ********************************************/
void MainWindow::closeEvent(QCloseEvent *event) {
	
      if (maybeSave()) {
            //writeSettings();
            event->accept();
      } 
	else 
            event->ignore();
      
}
/***************************************************************************************************************/
bool MainWindow::maybeSave()
{
      if (espace->activeWindow()) {
            int ret = QMessageBox::warning(this, tr("Application"),
                        tr("The document has been modified.\n"
                        "Do you want to save your changes?"),
                        QMessageBox::Yes | QMessageBox::Default,
                        QMessageBox::No,
                        QMessageBox::Cancel | QMessageBox::Escape);
            if (ret == QMessageBox::Yes)
	      true;//return save();
            else if (ret == QMessageBox::Cancel)
            return false;
      }
      return true;
}	
/*********************************** Implémentation de la méthode okToContinue ********************************************/
 bool MainWindow::okToContinue() {
 
         if (this->isWindowModified()) {
		int r = QMessageBox::warning(this, tr("Visual Yao"), tr("Le document a été modifié. \n "
						"Voulez-vous enregistrer les changements apportés?"),
						QMessageBox::Yes | QMessageBox::Default,
						QMessageBox::No,
						QMessageBox::Cancel | QMessageBox::Escape);
		if (r == QMessageBox::Yes) 
			return true;
		else 
			if (r == QMessageBox::Cancel)
				return false; 
		}
	
	return true;
 }

/*********************************** Implémentation de la méthode genererSpace ********************************************/
/*
void MainWindow::genererCtin() {
cout << "moi moi moi moi moi";
    QStringList genCtin = m_ctinCopy->getDataCtin();

    ofstream description1(filepath.c_str(), ios::out | ios::binary | ios::trunc);
        if(!description1.is_open())
                throw ofstream::failure("couldn't create " + filename);
    for (QStringList::iterator it = genCtin.begin(); it != genCtin.end(); it++)
            description1 << it->toStdString() << endl;
}
  */
/*********************************** Implémentation de la methode du destructeur *********************************************/

MainWindow::~MainWindow() {



                    delete menuFichier;
                    delete menuEdition;
                    delete menuAffichage;
                    delete menuExecution;
                    delete menuConfig;
                    delete menuAide;
                    //delete nouveau;
                    delete actionFichierDescription;
                    delete actionFichierHat;
                    //delete actionModule;
                    delete actionFichierInstruction;
                    delete actionGrapheModulaire;
                    delete actionInfosProjet;
                    delete actionNouveauProjet;
                    delete actionOuvrirProjet;
                    delete actionOuvrirProjetsRecents;
                    //delete actionImporterProjet;
                    delete actionEnregistrerProjet;
                    delete actionEnregistrerSousProjet;
                    delete actionImprimerProjet;
                    delete actionSortieProjet;
                    delete actionAnnuler;
                    delete actionRevenir;
                    delete actionCouper;
                    delete actionCopier;
                    delete actionColler;
                    delete actionSelectionnerTout;
                    delete actionCacherBarreOutils;
                    delete actionCacherFenetreApercu;
                    delete actionCacherFenetreProjet;
                    delete actionCacherFenetreDialog;
                    delete actionPleinEcran;
                    delete actionGenerationD;
                    delete actionCompilation;
                    delete actionExecution;
                    delete actionEditeur;
                    delete actionDocYao;
                    delete actionRapport;
                    //delete m_defval;
                    //delete m_hatName;
                    delete m_optionButton;
                    delete m_trajButton;
                    delete m_spaceButton;
                    delete m_operaButton;
                    delete m_netwardButton;
                    delete m_modulButton;
                    delete m_ctinButton;
                    delete m_orderButton;
                    delete m_insertFCTButton;
                    delete yaoToolBar;
                    delete espace;
                    delete tableWidget;
}
/************************************* Fin du parametrage du destructeur ****************************************************/



